@@ -6,7 +6,7 @@ from kaplanmeier.kaplanmeier import (
 
 __author__ = 'Erdogan Tasksen'
 __email__ = 'erdogant@gmail.com'
-__version__ = '0.1.6'
+__version__ = '0.1.8'
 
 # module level doc-string
 __doc__ = """
@@ -30,9 +30,9 @@ Example
 >>> # Plot
 >>> km.plot(results)
 >>>
->>> km.plot(out, cmap='Set1', cii_lines=True, cii_alpha=0.05)
->>> km.plot(out, cmap=[(1, 0, 0),(0, 0, 1)])
->>> km.plot(out, cmap='Set1', methodtype='custom')
+>>> km.plot(results, cmap='Set1', cii_lines='lifelines', cii_alpha=0.05)
+>>> km.plot(results, cmap=[(1, 0, 0),(0, 0, 1)])
+>>> km.plot(results, cmap='Set1', methodtype='custom')
 >>>
 >>> results['logrank_P']
 >>> results['logrank_Z']
